#!python

import sys
import copy

SIDE_X_POS = 0
SIDE_X_NEG = 1
SIDE_Y_POS = 2
SIDE_Y_NEG = 3
SIDE_Z_POS = 4
SIDE_Z_NEG = 5

def side_name(side):
    if( side == SIDE_X_POS ):
        return "SIDE_X_POS"
    if( side == SIDE_Y_POS ):
        return "SIDE_Y_POS"
    if( side == SIDE_Z_POS ):
        return "SIDE_Z_POS"
    if( side == SIDE_X_NEG ):
        return "SIDE_X_NEG"
    if( side == SIDE_Y_NEG ):
        return "SIDE_Y_NEG"
    if( side == SIDE_Z_NEG ):
        return "SIDE_Z_NEG"

#The data structures.
bound_to_rects_dict = {}
rect_to_str_dict = {}

class Block:
    x = -1
    y = -1
    z = -1

    def __init__(self, x,y,z):
        self.x = x
        self.y = y
        self.z = z

    def __eq__(a,b):
        return (a.x==b.x and a.y==b.y and a.z==b.z)

    def __add__(self, o):
        new = Block(-1,-1,-1)
        new.x = self.x + o.x
        new.y = self.y + o.y
        new.z = self.z + o.z
        return new

    def dump(self):
        print("Block: ")
        print("  x = " + str(self.x))
        print("  y = " + str(self.y))
        print("  z = " + str(self.z))

class Rect:
    min_pos = Block(-1,-1,-1)
    max_pos = Block(-1,-1,-1)

    def __init__(self):
        self.min_pos = Block(-1,1,1)
        self.max_pos = Block(-1,1,1)

    def __eq__(a,b):
        return (a.min_pos==b.min_pos and a.max_pos==b.max_pos)

    def __hash__(self):
        #Taking a linear combination of large primes.
        n1 = self.min_pos.x * 1000003
        n2 = self.min_pos.y * 1000033
        n3 = self.min_pos.z * 1000037
        n4 = self.max_pos.x * 1000039
        n5 = self.max_pos.y * 1000081
        n6 = self.max_pos.z * 1000099
        return n1+n2+n3+n4+n5+n6

    def set_from_pos(self, x,y,z):
        pos = Block(x,y,z)
        self.min_pos = pos
        self.max_pos = pos

    def volume(self):
        w_x = (self.max_pos.x - self.min_pos.x) + 1
        w_y = (self.max_pos.y - self.min_pos.y) + 1
        w_z = (self.max_pos.z - self.min_pos.z) + 1
        return w_x * w_y * w_z

    def dump(self):
        print("Rect:")
        print("  min_x = " + str(self.min_pos.x))
        print("  min_y = " + str(self.min_pos.y))
        print("  min_z = " + str(self.min_pos.z))
        print("  max_x = " + str(self.max_pos.x))
        print("  max_y = " + str(self.max_pos.y))
        print("  max_z = " + str(self.max_pos.z))

def rects_disjoint(r1, r2):
    if( r1.max_pos.x < r2.min_pos.x ):
        return True
    if( r1.max_pos.y < r2.min_pos.y ):
        return True
    if( r1.max_pos.z < r2.min_pos.z ):
        return True
    if( r2.max_pos.x < r1.min_pos.x ):
        return True
    if( r2.max_pos.y < r1.min_pos.y ):
        return True
    if( r2.max_pos.z < r1.min_pos.z ):
        return True
    return False

def union_rects(r1, r2):
    r = Rect()
    r.min_pos.x = min(r1.min_pos.x, r2.min_pos.x)
    r.min_pos.y = min(r1.min_pos.y, r2.min_pos.y)
    r.min_pos.z = min(r1.min_pos.z, r2.min_pos.z)
    r.max_pos.x = max(r1.max_pos.x, r2.max_pos.x)
    r.max_pos.y = max(r1.max_pos.y, r2.max_pos.y)
    r.max_pos.z = max(r1.max_pos.z, r2.max_pos.z)
    return r

def can_merge_rects(r1, r2):
    if not rects_disjoint(r1,r2):
        return False
    v1 = r1.volume()
    v2 = r2.volume()
    union = union_rects(r1,r2)
    v3 = union.volume()
    return (v1 + v2 == v3)

#side should be in the range [0,5].
def get_boundary(r, side):
    new_r = Rect()
    new_r.min_pos.x = r.min_pos.x
    new_r.min_pos.y = r.min_pos.y
    new_r.min_pos.z = r.min_pos.z
    new_r.max_pos.x = r.max_pos.x
    new_r.max_pos.y = r.max_pos.y
    new_r.max_pos.z = r.max_pos.z
    if( side == SIDE_X_POS ):
        new_r.min_pos.x = r.max_pos.x
    if( side == SIDE_Y_POS ):
        new_r.min_pos.y = r.max_pos.y
    if( side == SIDE_Z_POS ):
        new_r.min_pos.z = r.max_pos.z
    if( side == SIDE_X_NEG ):
        new_r.max_pos.x = r.min_pos.x
    if( side == SIDE_Y_NEG ):
        new_r.max_pos.y = r.min_pos.y
    if( side == SIDE_Z_NEG ):
        new_r.max_pos.z = r.min_pos.z
    return new_r

#side should be in the range [0,5].
def shift_rect(r, side):
    add = Block(0,0,0)
    if( side == SIDE_X_POS ):
        add = Block(1,0,0)
    if( side == SIDE_Y_POS ):
        add = Block(0,1,0)
    if( side == SIDE_Z_POS ):
        add = Block(0,0,1)
    if( side == SIDE_X_NEG ):
        add = Block(-1,0,0)
    if( side == SIDE_Y_NEG ):
        add = Block(0,-1,0)
    if( side == SIDE_Z_NEG ):
        add = Block(0,0,-1)
    new = Rect()
    new.min_pos = r.min_pos + add
    new.max_pos = r.max_pos + add
    return new

def remove_rect(r):
    for side in range(0,6):
        bound = get_boundary(r, side)
        if bound in bound_to_rects_dict:
            bound_to_rects_dict.pop(bound)
        else:
            #Uh oh!!!
            pass
    if r in rect_to_str_dict:
        rect_to_str_dict.pop(r)
    else:
        #Uh oh!!!
        pass

def add_rect(r, str_data):
    #Checking boundaries
    #for a possible merge.
    for side in range(0,6):
        b = get_boundary(r,side)
        sb = shift_rect(b,side)
        if sb in bound_to_rects_dict:
            # print("shifted boundary found...")
            #There is an adjacent rect to r
            #that can be merged with r.
            adj_rect = bound_to_rects_dict[sb]
            adj_str = rect_to_str_dict[adj_rect]
            if( str_data == adj_str ):
                #The two adjacent rect have the
                #same string, so they really an be merged.
                #However, doing a saftey check anyway.
                if( can_merge_rects(r, adj_rect) ):
                    union = union_rects(r, adj_rect)
                    #The recursive step.
                    remove_rect(adj_rect)
                    add_rect(union, str_data)
                    return
    #Could not successfully merge.
    #Simply adding the unmerged block_rect.
    rect_to_str_dict[r] = str_data
    for side in range(0,6):
        b = get_boundary(r,side)
        bound_to_rects_dict[b] = r

def add_block(x,y,z, str):
    r = Rect()
    r.set_from_pos(x,y,z)
    add_rect(r, str)

#Reading from stdin.
for line in sys.stdin:
    #Seeing if is a comment.
    if( len(line) == 0 ):
        continue
    if( line.isspace() ):
        continue
    if( line[0] == '#' ):
        continue

    #Iterating through the line.
    i = 0

    str1 = ""
    while( i < len(line) ):
        c = line[i]
        i += 1
        if( c == ' ' ):
            break
        str1 += str(c)
    x = int(str1)
    
    str2 = ""
    while( i < len(line) ):
        c = line[i]
        i += 1
        if( c == ' ' ):
            break
        str2 += str(c)
    y = int(str2)

    str3 = ""
    while( i < len(line) ):
        c = line[i]
        i += 1
        if( c == ' ' ):
            break
        str3 += str(c)
    z = int(str3)

    quoted = line.split('"')[1::2]
    block_type = quoted[0]

    #Adding the new block.
    add_block(x,y,z, block_type)

#Printing to stdout.
for key in rect_to_str_dict:
    value = rect_to_str_dict[key]
    #
    line = ""
    line += str(key.min_pos.x) + " "
    line += str(key.min_pos.y) + " "
    line += str(key.min_pos.z) + " "
    line += str(key.max_pos.x) + " "
    line += str(key.max_pos.y) + " "
    line += str(key.max_pos.z) + " "
    line += value
    print(line)
